@@ -35,7 +35,7 @@ class ScilabCompletionObject : public Cantor::CompletionObject
         virtual bool mayIdentifierContain(QChar c) const;
         virtual bool mayIdentifierBeginWith(QChar c) const;
 
-    protected slots:
+    protected Q_SLOTS:
         void fetchCompletions();
         void fetchIdentifierType();
 };
