@@ -26,8 +26,6 @@
 
 #include <QList>
 
-#include <KParts/ReadWritePart>
-
 class QTabWidget;
 class KTextEdit;
 
@@ -35,6 +33,10 @@ namespace Cantor{
 class WorksheetAccessInterface;
 }
 
+namespace KParts{
+    class ReadWritePart;
+}
+
 /**
  * This is the application "Shell".  It has a menubar, toolbar, and
  * statusbar but relies on the "Part" to do all the real work.
